==> dmc-sdk-5.3.2.1-sources.jar: com/digiwin/dap/middleware/dmc/model/FileInfo.java <==
package com.digiwin.dap.middleware.dmc.model;

import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.Map;

/**
 * 文件
 *
 * @author fobgochod
 * @since 3.1.0.0
 */
public class FileInfo extends BaseEntity {

    private String fileName;
    private String displayName;
    private String description;
    private String tag;
    private long size;
    private String extension;
    private String contentType;
    private LocalDateTime expireDate;
    private LocalDateTime coverDate;
    private String directoryId;
    private String directoryName;
    private Map<String, Object> metadata = new HashMap<>();
    private boolean needModerator = false;

    public FileInfo() {
    }

    public FileInfo(String fileName) {
        this.fileName = fileName;
    }

    public FileInfo(String fileName, String directoryId) {
        this.fileName = fileName;
        this.directoryId = directoryId;
    }

    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public String getDisplayName() {
        return displayName;
    }

    public void setDisplayName(String displayName) {
        this.displayName = displayName;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }

    public long getSize() {
        return size;
    }

    public void setSize(long size) {
        this.size = size;
    }

    public String getExtension() {
        return extension;
    }

    public void setExtension(String extension) {
        this.extension = extension;
    }

    public String getContentType() {
        return contentType;
    }

    public void setContentType(String contentType) {
        this.contentType = contentType;
    }

    public LocalDateTime getExpireDate() {
        return expireDate;
    }

    public void setExpireDate(LocalDateTime expireDate) {
        this.expireDate = expireDate;
    }

    public LocalDateTime getCoverDate() {
        return coverDate;
    }

    public void setCoverDate(LocalDateTime coverDate) {
        this.coverDate = coverDate;
    }

    public String getDirectoryId() {
        return directoryId;
    }

    public void setDirectoryId(String directoryId) {
        this.directoryId = directoryId;
    }

    public String getDirectoryName() {
        return directoryName;
    }

    public void setDirectoryName(String directoryName) {
        this.directoryName = directoryName;
    }

    public Map<String, Object> getMetadata() {
        return metadata;
    }

    public void setMetadata(Map<String, Object> metadata) {
        this.metadata = metadata;
    }

    public boolean isNeedModerator() {
        return needModerator;
    }

    public void setNeedModerator(boolean needModerator) {
        this.needModerator = needModerator;
    }

    @Override
    public String toString() {
        return "FileInfo{" +
                "fileName='" + fileName + '\'' +
                ", displayName='" + displayName + '\'' +
                ", description='" + description + '\'' +
                ", tag='" + tag + '\'' +
                ", size=" + size +
                ", extension='" + extension + '\'' +
                ", contentType='" + contentType + '\'' +
                ", expireDate=" + expireDate +
                ", coverDate=" + coverDate +
                ", directoryId='" + directoryId + '\'' +
                ", directoryName='" + directoryName + '\'' +
                ", metadata=" + metadata +
                ", needModerator=" + needModerator +
                '}';
    }
}

==> dmc-sdk-5.4.0.0-sources.jar: com/digiwin/dap/middleware/dmc/model/FileInfo.java <==
package com.digiwin.dap.middleware.dmc.model;

import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.Map;

/**
 * 文件
 *
 * @author fobgochod
 * @since 3.1.0.0
 */
public class FileInfo extends BaseEntity {

    private String fileName;
    private String displayName;
    private String description;
    private String tag;
    private long size;
    private String extension;
    private String contentType;
    private LocalDateTime expireDate;
    private LocalDateTime coverDate;
    private String directoryId;
    private String directoryName;
    private Map<String, Object> metadata = new HashMap<>();
    private boolean needModerator = false;
    private String uploadScene;
    private ReadPermission readPermission = ReadPermission.TENANT;
    private WritePermission writePermission = WritePermission.TENANT;

    public FileInfo() {
    }

    public FileInfo(String fileName) {
        this.fileName = fileName;
    }

    public FileInfo(String fileName, String directoryId) {
        this.fileName = fileName;
        this.directoryId = directoryId;
    }

    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public String getDisplayName() {
        return displayName;
    }

    public void setDisplayName(String displayName) {
        this.displayName = displayName;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }

    public long getSize() {
        return size;
    }

    public void setSize(long size) {
        this.size = size;
    }

    public String getExtension() {
        return extension;
    }

    public void setExtension(String extension) {
        this.extension = extension;
    }

    public String getContentType() {
        return contentType;
    }

    public void setContentType(String contentType) {
        this.contentType = contentType;
    }

    public LocalDateTime getExpireDate() {
        return expireDate;
    }

    public void setExpireDate(LocalDateTime expireDate) {
        this.expireDate = expireDate;
    }

    public LocalDateTime getCoverDate() {
        return coverDate;
    }

    public void setCoverDate(LocalDateTime coverDate) {
        this.coverDate = coverDate;
    }

    public String getDirectoryId() {
        return directoryId;
    }

    public void setDirectoryId(String directoryId) {
        this.directoryId = directoryId;
    }

    public String getDirectoryName() {
        return directoryName;
    }

    public void setDirectoryName(String directoryName) {
        this.directoryName = directoryName;
    }

    public Map<String, Object> getMetadata() {
        return metadata;
    }

    public void setMetadata(Map<String, Object> metadata) {
        this.metadata = metadata;
    }

    public boolean isNeedModerator() {
        return needModerator;
    }

    public void setNeedModerator(boolean needModerator) {
        this.needModerator = needModerator;
    }

    public String getUploadScene() {
        return uploadScene;
    }

    public void setUploadScene(String uploadScene) {
        this.uploadScene = uploadScene;
    }

    public ReadPermission getReadPermission() {
        return readPermission;
    }

    public void setReadPermission(ReadPermission readPermission) {
        this.readPermission = readPermission;
    }

    public WritePermission getWritePermission() {
        return writePermission;
    }

    public void setWritePermission(WritePermission writePermission) {
        this.writePermission = writePermission;
    }

    @Override
    public String toString() {
        return "FileInfo{" +
                "fileName='" + fileName + '\'' +
                ", displayName='" + displayName + '\'' +
                ", description='" + description + '\'' +
                ", tag='" + tag + '\'' +
                ", size=" + size +
                ", extension='" + extension + '\'' +
                ", contentType='" + contentType + '\'' +
                ", expireDate=" + expireDate +
                ", coverDate=" + coverDate +
                ", directoryId='" + directoryId + '\'' +
                ", directoryName='" + directoryName + '\'' +
                ", metadata=" + metadata +
                ", needModerator=" + needModerator +
                ", uploadScene='" + uploadScene + '\'' +
                ", readPermission=" + readPermission +
                ", writePermission=" + writePermission +
                '}';
    }
}
